@@ -464,7 +464,7 @@ Virtual Machines.  OVMF contains a sample UEFI firmware for QEMU and KVM.")
 (define* (make-arm-trusted-firmware platform #:optional (arch "aarch64"))
   (package
     (name (string-append "arm-trusted-firmware-" platform))
-    (version "2.3")
+    (version "2.4")
     (source
       (origin
         (method git-fetch)
@@ -475,7 +475,7 @@ Virtual Machines.  OVMF contains a sample UEFI firmware for QEMU and KVM.")
         (file-name (git-file-name "arm-trusted-firmware" version))
        (sha256
         (base32
-         "113mcf1hwwl0i90cqh08lywxs1bfbg0nwqibay9wlkmx1a5v0bnj"))))
+         "12k0n79j156bdzqws18kpbli04kn00nh6dy42pjv6gakqrkx9px3"))))
     (build-system gnu-build-system)
     (arguments
      `(#:phases
@@ -512,17 +512,18 @@ Virtual Machines.  OVMF contains a sample UEFI firmware for QEMU and KVM.")
     (native-inputs
      `(,@(if (and (not (string-prefix? "aarch64" (%current-system)))
                   (string-prefix? "aarch64" arch))
-           ;; gcc-7 since it is used for u-boot, which needs gcc-7.
-           `(("cross-gcc" ,(cross-gcc "aarch64-linux-gnu" #:xgcc gcc-7))
+           ;; Needs newer gcc version for some targets
+           `(("cross-gcc" ,(cross-gcc "aarch64-linux-gnu" #:xgcc gcc-9))
              ("cross-binutils" ,(cross-binutils "aarch64-linux-gnu")))
            '())
        ,@(if (and (not (string-prefix? "armhf" (%current-system)))
                   (string-prefix? "armhf" arch))
-           ;; gcc-7 since it is used for u-boot, which needs gcc-7.
-           `(("cross-gcc" ,(cross-gcc "arm-linux-gnueabihf" #:xgcc gcc-7))
+           ;; Needs newer gcc version for some targets
+           `(("cross-gcc" ,(cross-gcc "arm-linux-gnueabihf" #:xgcc gcc-9))
              ("cross-binutils" ,(cross-binutils "arm-linux-gnueabihf")))
            '())
-        ))
+       ;; Needs newer gcc version for some targets
+       ("gcc" ,gcc-9)))
     (home-page "https://www.trustedfirmware.org/")
     (synopsis "Implementation of \"secure world software\"")
     (description
@@ -549,26 +550,6 @@ such as:
 (define-public arm-trusted-firmware-rk3328
   (make-arm-trusted-firmware "rk3328"))
 
-(define-public arm-trusted-firmware-puma-rk3399
-  (let ((base (make-arm-trusted-firmware "rk3399"))
-        ;; Vendor's arm trusted firmware branch hasn't been upstreamed yet.
-        (commit "d71e6d83612df896774ec4c03d49500312d2c324")
-        (revision "1"))
-    (package
-      (inherit base)
-      (name "arm-trusted-firmware-puma-rk3399")
-      (version (git-version "1.3" revision commit))
-      (source
-        (origin
-          (method git-fetch)
-          (uri (git-reference
-                 (url "https://git.theobroma-systems.com/arm-trusted-firmware.git")
-                 (commit commit)))
-          (file-name (git-file-name name version))
-          (sha256
-           (base32
-            "0vqhwqqh8h9qlkpybg2v94911091c1418bc4pnzq5fd7zf0fjkf8")))))))
-
 (define-public arm-trusted-firmware-rk3399
   (let ((base (make-arm-trusted-firmware "rk3399")))
     (package
@@ -578,46 +559,3 @@ such as:
        `(("cross32-gcc" ,(cross-gcc "arm-none-eabi"))
          ("cross32-binutils", (cross-binutils "arm-none-eabi"))
          ,@(package-native-inputs base))))))
-
-(define-public rk3399-cortex-m0
-  (package
-    (name "rk3399-cortex-m0")
-    (version "1")
-    (source
-     (origin
-       (method git-fetch)
-       (uri (git-reference
-             (url "https://git.theobroma-systems.com/rk3399-cortex-m0.git")
-             (commit (string-append "v" version))))
-       (file-name (git-file-name "rk3399-cortex-m0" version))
-       (sha256
-        (base32
-         "02wz1vkf4j3zc8rx289z76xhrf71jhb2p05lvmygky393a9gjh9w"))))
-    (home-page "https://git.theobroma-systems.com/rk3399-cortex-m0.git/about/")
-    (synopsis "PMU Cortex M0 firmware for RK3399 Q7 (Puma)")
-    (description
-     "Cortex-M0 firmware used with the RK3399 to implement
-power-management functionality and helpers (e.g. DRAM frequency
-switching support).\n")
-    (license license:bsd-3)
-    (build-system gnu-build-system)
-    (arguments
-     `(#:phases
-       (modify-phases %standard-phases
-         (delete 'configure)
-         (delete 'check)
-         (replace 'install
-           (lambda* (#:key outputs #:allow-other-keys)
-             (let ((out (assoc-ref outputs "out"))
-                   (mzerofiles (find-files "." "rk3399m0.(elf|bin)$")))
-               (for-each
-                 (lambda (file)
-                   (install-file file out))
-                 mzerofiles))
-             #t))
-         (add-before 'build 'setenv
-           (lambda* (#:key inputs #:allow-other-keys)
-             (setenv "CROSS_COMPILE" "arm-none-eabi-")
-             #t)))))
-    (native-inputs `(("cross-gcc" ,(cross-gcc "arm-none-eabi" #:xgcc gcc-7))
-                     ("cross-binutils" ,(cross-binutils "arm-none-eabi"))))))
