@@ -1,5 +1,8 @@
 ;;; GNU Guix --- Functional package management for GNU
 ;;; Copyright © 2013 Eric Bavier <bavier@member.fsf.org>
+;;; Copyright © 2015 Mark H Weaver <mhw@netris.org>
+;;; Copyright © 2016, 2018, 2020 Efraim Flashner <efraim@flashner.co.il>
+;;; Copyright © 2020 Tobias Geerinckx-Rice <me@tobias.gr>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -22,23 +25,38 @@
   #:use-module (guix download)
   #:use-module (guix build-system gnu)
   #:use-module (gnu packages)
-  #:use-module (gnu packages which))
+  #:use-module (gnu packages base)
+  #:use-module (gnu packages autogen))
 
 (define-public gnu-pw-mgr
   (package
     (name "gnu-pw-mgr")
-    (version "1.2")
+    (version "2.7.4")
     (source
      (origin
       (method url-fetch)
       (uri (string-append "mirror://gnu/gnu-pw-mgr/gnu-pw-mgr-"
-                          version ".tar.gz"))
+                          version ".tar.xz"))
       (sha256
-       (base32
-        "0rdindczxq8ysm3qq7ghc7pcvhp6bn6fadlwna8p83vc1n9nd5py"))))
+       (base32 "0fhwvsmsqpw0vnivarfg63l8pgwqfv7d5wi6l80jpb41dj6qpjz8"))))
     (build-system gnu-build-system)
-    (inputs `(("which" ,which)))
-    (home-page "http://www.gnu.org/software/gnu-pw-mgr/")
+    (arguments
+     '(#:phases
+       (modify-phases %standard-phases
+         (add-after 'patch-source-shebangs 'patch-more-shebangs
+           (lambda _
+             (substitute* "tests/dom.test"
+               (("/usr/bin/printf") (which "printf")))
+             #t))
+         (add-before 'check 'pre-check
+           (lambda _
+             ;; In the build environment, there is no /dev/tty.
+             (substitute* "tests/base.test"
+               (("/dev/tty") "/dev/null"))
+             #t)))))
+    (native-inputs
+     `(("which" ,which)))
+    (home-page "https://www.gnu.org/software/gnu-pw-mgr/")
     (synopsis "Retrieve login credentials without recording passwords")
     (description
      "This program is designed to make it easy to reconstruct difficult
