@@ -15,6 +15,8 @@
 ;;; Copyright © 2019, 2020 Alex Griffin <a@ajgrf.com>
 ;;; Copyright © 2020 Alexandru-Sergiu Marton <brown121407@member.fsf.org>
 ;;; Copyright © 2020 Brian Leung <bkleung89@gmail.com>
+;;; Copyright © 2021 EuAndreh <eu@euandre.org>
+;;; Copyright © 2021 Stefan Reichör <stefan@xsteve.at>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -49,7 +51,8 @@
   #:use-module (gnu packages perl)
   #:use-module (gnu packages pkg-config)
   #:use-module (gnu packages rsync)
-  #:use-module (gnu packages version-control))
+  #:use-module (gnu packages version-control)
+  #:use-module (gnu packages xorg))
 
 (define-public apply-refact
   (package
@@ -339,14 +342,14 @@ to @code{cabal repl}).")
 (define-public git-annex
   (package
     (name "git-annex")
-    (version "8.20201007")
+    (version "8.20210330")
     (source
      (origin
        (method url-fetch)
        (uri (string-append "https://hackage.haskell.org/package/"
                            "git-annex/git-annex-" version ".tar.gz"))
        (sha256
-        (base32 "0v11yc4kkxnzvwqry277dpjwlavinrjiagfw0ayhrfwd703j1y8a"))))
+        (base32 "07dhxlmnj48drgndcplafc7xhby0w3rks68fz9wsppxan929240p"))))
     (build-system haskell-build-system)
     (arguments
      `(#:configure-flags
@@ -487,6 +490,7 @@ to @code{cabal repl}).")
        ("ghc-split" ,ghc-split)
        ("ghc-stm-chans" ,ghc-stm-chans)
        ("ghc-tagsoup" ,ghc-tagsoup)
+       ("ghc-torrent" ,ghc-torrent)
        ("ghc-unix-compat" ,ghc-unix-compat)
        ("ghc-unordered-containers" ,ghc-unordered-containers)
        ("ghc-utf8-string" ,ghc-utf8-string)
@@ -689,6 +693,69 @@ By operating at a lower level than most similar tools, it supports X11,
 Wayland, and Linux console environments alike.")
     (license license:expat)))
 
+(define-public nixfmt
+  (package
+    (name "nixfmt")
+    (version "0.4.0")
+    (source
+     (origin
+       (method url-fetch)
+       (uri (string-append
+             "https://hackage.haskell.org/package/nixfmt/nixfmt-"
+             version
+             ".tar.gz"))
+       (sha256
+        (base32 "1ispgl8rc2scr6v8bb6sks7px856jf61x74zj2iyddrn5qamkb3n"))))
+    (build-system haskell-build-system)
+    (inputs
+     `(("ghc-megaparsec" ,ghc-megaparsec)
+       ("ghc-parser-combinators" ,ghc-parser-combinators)
+       ("ghc-cmdargs" ,ghc-cmdargs)
+       ("ghc-safe-exceptions" ,ghc-safe-exceptions)))
+    (arguments
+     `(#:cabal-revision
+       ("1" "1hsj0jh6siph3afd9c2wii09sffl48rzqv653n4clpd8qy0rn48d")))
+    (home-page "https://github.com/serokell/nixfmt")
+    (synopsis "Opinionated formatter for Nix")
+    (description
+     "Nixfmt is a formatter for Nix that ensures consistent and clear
+formatting by forgetting all existing formatting during parsing.")
+    (license license:mpl2.0)))
+
+(define-public greenclip
+  (package
+    (name "greenclip")
+    (version "3.4")
+    (source
+     (origin
+       (method git-fetch)
+       (uri (git-reference
+             (url "https://github.com/erebe/greenclip")
+             (commit version)))
+       (file-name (git-file-name name version))
+       (sha256
+        (base32 "1baw360dcnyavacf7a8v6wq4m5g6bcmyybkckv4cz7r4xl5p3qws"))))
+    (build-system haskell-build-system)
+    (native-inputs
+     `(("pkg-config" ,pkg-config)))
+    (inputs
+     `(("libx11" ,libx11)
+       ("libxext" ,libxext)
+       ("libxscrnsaver" ,libxscrnsaver)
+       ("ghc-x11" ,ghc-x11)
+       ("ghc-exceptions" ,ghc-exceptions)
+       ("ghc-hashable" ,ghc-hashable)
+       ("ghc-microlens" ,ghc-microlens)
+       ("ghc-microlens-mtl" ,ghc-microlens-mtl)
+       ("ghc-protolude" ,ghc-protolude-0.3)
+       ("ghc-vector" ,ghc-vector)
+       ("ghc-wordexp" ,ghc-wordexp)))
+    (home-page "https://github.com/erebe/greenclip")
+    (synopsis "Simple Clipboard manager")
+    (description "@code{greenclip} is a clipboard manager written in
+Haskell.")
+    (license license:bsd-3)))
+
 (define-public raincat
   (package
     (name "raincat")
