@@ -75,12 +75,12 @@ IPv4 and IPv6.  ONC RPC is notably used by the network file system (NFS).")
     (license bsd-3)))
 
 (define-public libtirpc/hurd
-  (package
-    (inherit libtirpc)
+  (package/inherit libtirpc
     (name "libtirpc-hurd")
     (source (origin (inherit (package-source libtirpc))
-                    (patches (search-patches "libtirpc-hurd.patch"
-                                             "libtirpc-hurd-client.patch"))))
+                    (patches (append (origin-patches (package-source libtirpc))
+                                     (search-patches "libtirpc-hurd.patch"
+                                                     "libtirpc-hurd-client.patch")))))
     (arguments
      (substitute-keyword-arguments (package-arguments libtirpc)
        ((#:configure-flags flags ''())
@@ -92,7 +92,7 @@ IPv4 and IPv6.  ONC RPC is notably used by the network file system (NFS).")
 (define-public rpcbind
   (package
     (name "rpcbind")
-    (version "0.2.4")
+    (version "1.2.5")
     (source
      (origin
       (method url-fetch)
@@ -102,7 +102,7 @@ IPv4 and IPv6.  ONC RPC is notably used by the network file system (NFS).")
       (patches (search-patches "rpcbind-CVE-2017-8779.patch"))
       (sha256
        (base32
-        "0rjc867mdacag4yqvs827wqhkh27135rp9asj06ixhf71m9rljh7"))))
+        "0ynszy5hpc7wbz8xngqwyhgbi9cay73y43izqhcmrcv375l61qrc"))))
     (build-system gnu-build-system)
     (arguments
      `(#:configure-flags
@@ -143,7 +143,7 @@ from the protocol files.")
 (define-public libnsl
   (package
     (name "libnsl")
-    (version "1.2.0")
+    (version "1.3.0")
     (source (origin
               (method git-fetch)
               (uri (git-reference
@@ -152,17 +152,10 @@ from the protocol files.")
               (file-name (git-file-name name version))
               (sha256
                (base32
-                "1chzqhcgh0yia9js8mh92cmhyka7rh32ql6b3mgdk26n94dqzs8b"))))
+                "1dayj5i4bh65gn7zkciacnwv2a0ghm6nn58d78rsi4zby4lyj5w5"))))
     (build-system gnu-build-system)
     (arguments
-     `(#:configure-flags '("--disable-static")
-       #:phases (modify-phases %standard-phases
-                  (add-before 'bootstrap 'gettextize
-                    (lambda _
-                      ;; Regenerate the bundled Makefile.in.in to avoid a
-                      ;; "gettext infrastructure mismatch" because the
-                      ;; existing version was generated by an older gettext.
-                      (invoke "gettextize" "-f"))))))
+     `(#:configure-flags '("--disable-static")))
     (native-inputs
      `(("autoconf" ,autoconf)
        ("automake" ,automake)
