@@ -1,5 +1,7 @@
 ;;; GNU Guix --- Functional package management for GNU
-;;; Copyright © 2016, 2017 Ricardo Wurmus <rekado@elephly.net>
+;;; Copyright © 2016, 2017, 2018 Ricardo Wurmus <rekado@elephly.net>
+;;; Copyright © 2018 Tobias Geerinckx-Rice <me@tobias.gr>
+;;; Copyright © 2019, 2020 Marius Bakke <mbakke@fastmail.com>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -20,6 +22,7 @@
   #:use-module ((guix licenses) #:prefix license:)
   #:use-module (guix packages)
   #:use-module (guix download)
+  #:use-module (guix git-download)
   #:use-module (guix utils)
   #:use-module (guix build-system gnu)
   #:use-module (guix build-system python)
@@ -35,8 +38,8 @@
   #:use-module (gnu packages pcre)
   #:use-module (gnu packages pkg-config)
   #:use-module (gnu packages python)
+  #:use-module (gnu packages python-xyz)
   #:use-module (gnu packages swig)
-  #:use-module (gnu packages textutils)
   #:use-module (gnu packages xml))
 
 ;; Update the SELinux packages together!
@@ -44,34 +47,47 @@
 (define-public libsepol
   (package
     (name "libsepol")
-    (version "2.6")
-    (source (let ((release "20161014"))
+    (version "3.0")
+    (source (let ((release "20191204"))
               (origin
-                (method url-fetch)
-                (uri (string-append "https://github.com/SELinuxProject/selinux/"
-                                    "archive/" release ".tar.gz"))
-                (file-name (string-append "selinux-" release ".tar.gz"))
+                (method git-fetch)
+                (uri (git-reference
+                      (url "https://github.com/SELinuxProject/selinux")
+                      (commit release)))
+                (file-name (string-append "selinux-" release "-checkout"))
                 (sha256
                  (base32
-                  "1dpwynfb6n31928343blac4159g4jbrwxdp61q5yffmxpy3c3czi")))))
+                  "05rpzm72cgprd0ccr6lvx9hm8j8b5nkqi4avshlsyg7s3sdlcxjs")))))
     (build-system gnu-build-system)
     (arguments
      `(#:tests? #f ; tests require checkpolicy, which requires libsepol
        #:test-target "test"
        #:make-flags
-       (let ((out (assoc-ref %outputs "out")))
+       (let ((out (assoc-ref %outputs "out"))
+             (target ,(%current-target-system)))
          (list (string-append "PREFIX=" out)
-               (string-append "DESTDIR=" out)
+               (string-append "SHLIBDIR=" out "/lib")
                (string-append "MAN3DIR=" out "/share/man/man3")
                (string-append "MAN5DIR=" out "/share/man/man5")
                (string-append "MAN8DIR=" out "/share/man/man8")
                (string-append "LDFLAGS=-Wl,-rpath=" out "/lib")
-               "CC=gcc"))
+               (string-append "CC="
+                              (if target
+                                  (string-append (assoc-ref %build-inputs "cross-gcc")
+                                                 "/bin/" target "-gcc")
+                                  "gcc"))))
        #:phases
        (modify-phases %standard-phases
          (delete 'configure)
          (add-after 'unpack 'enter-dir
-           (lambda _ (chdir ,name) #t)))))
+           (lambda _ (chdir ,name) #t))
+         (add-after 'enter-dir 'portability
+           (lambda _
+             (substitute* "src/ibpkeys.c"
+               (("#include \"ibpkey_internal.h\"" line)
+                (string-append line "\n#include <inttypes.h>\n"))
+               (("%#lx") "%#\" PRIx64 \""))
+             #t)))))
     (native-inputs
      `(("flex" ,flex)))
     (home-page "https://selinuxproject.org/")
@@ -85,22 +101,26 @@ boolean settings).")
     (license license:lgpl2.1+)))
 
 (define-public checkpolicy
-  (package (inherit libsepol)
+  (package/inherit libsepol
     (name "checkpolicy")
     (arguments
      `(#:tests? #f ; there is no check target
        #:make-flags
-       (let ((out (assoc-ref %outputs "out")))
+       (let ((out (assoc-ref %outputs "out"))
+             (target ,(%current-target-system)))
          (list (string-append "PREFIX=" out)
-               (string-append "LDLIBS="
+               (string-append "LIBSEPOLA="
                               (assoc-ref %build-inputs "libsepol")
-                              "/lib/libsepol.a "
-                              (assoc-ref %build-inputs "flex")
-                              "/lib/libfl.a")
-               "CC=gcc"))
+                              "/lib/libsepol.a")
+               (string-append "CC="
+                              (if target
+                                  (string-append (assoc-ref %build-inputs "cross-gcc")
+                                                 "/bin/" target "-gcc")
+                                  "gcc"))))
        #:phases
        (modify-phases %standard-phases
          (delete 'configure)
+         (delete 'portability)
          (add-after 'unpack 'enter-dir
            (lambda _ (chdir ,name) #t)))))
     (inputs
@@ -119,44 +139,39 @@ module into a binary representation.")
     (license license:gpl2)))
 
 (define-public libselinux
-  (package (inherit libsepol)
+  (package/inherit libsepol
     (name "libselinux")
+    (outputs '("out" "python"))
     (arguments
      (substitute-keyword-arguments (package-arguments libsepol)
        ((#:make-flags flags)
         `(cons* "PYTHON=python3"
-                (string-append "PYSITEDIR="
-                               (assoc-ref %outputs "out")
+                (string-append "LIBSEPOLA="
+                              (assoc-ref %build-inputs "libsepol")
+                              "/lib/libsepol.a")
+                (string-append "PYTHONLIBDIR="
+                               (assoc-ref %outputs "python")
                                "/lib/python"
                                ,(version-major+minor (package-version python))
                                "/site-packages/")
                 ,flags))
        ((#:phases phases)
         `(modify-phases ,phases
+           (delete 'portability)
            (replace 'enter-dir
              (lambda _ (chdir ,name) #t))
-           ;; libsepol.a is not located in this package's LIBDIR.
-           (add-after 'enter-dir 'patch-libsepol-path
-             (lambda* (#:key inputs #:allow-other-keys)
-               (substitute* "src/Makefile"
-                 (("\\$\\(LIBDIR\\)/libsepol.a")
-                  (string-append (assoc-ref inputs "libsepol")
-                                 "/lib/libsepol.a")))
-               #t))
-           (add-after 'enter-dir 'remove-Werror
-             (lambda _
-               ;; GCC complains about the fact that the output does not (yet)
-               ;; have an "include" directory, even though it is referenced.
-               (substitute* '("src/Makefile"
-                              "utils/Makefile")
-                 (("-Werror ") ""))
-               #t))
            (add-after 'build 'pywrap
              (lambda* (#:key make-flags #:allow-other-keys)
-               (zero? (apply system* "make" "pywrap" make-flags))))
+               (apply invoke "make" "pywrap" make-flags)))
            (add-after 'install 'install-pywrap
-             (lambda* (#:key make-flags #:allow-other-keys)
-               (zero? (apply system* "make" "install-pywrap" make-flags))))))))
+             (lambda* (#:key make-flags outputs #:allow-other-keys)
+               ;; The build system uses "python setup.py install" to install
+               ;; Python bindings.  Instruct it to use the correct output.
+               (substitute* "src/Makefile"
+                 (("--prefix=\\$\\(PREFIX\\)")
+                  (string-append "--prefix=" (assoc-ref outputs "python"))))
+
+               (apply invoke "make" "install-pywrap" make-flags)))))))
     ;; These libraries are in "Requires.private" in libselinux.pc.
     (propagated-inputs
      `(("libsepol" ,libsepol)
@@ -178,13 +193,13 @@ the core SELinux management utilities.")
     (license license:public-domain)))
 
 (define-public libsemanage
-  (package (inherit libsepol)
+  (package/inherit libsepol
     (name "libsemanage")
     (arguments
      (substitute-keyword-arguments (package-arguments libsepol)
        ((#:make-flags flags)
         `(cons* "PYTHON=python3"
-                (string-append "PYSITEDIR="
+                (string-append "PYTHONLIBDIR="
                                (assoc-ref %outputs "out")
                                "/lib/python"
                                ,(version-major+minor (package-version python))
@@ -192,19 +207,25 @@ the core SELinux management utilities.")
                 ,flags))
        ((#:phases phases)
         `(modify-phases ,phases
+           (delete 'portability)
            (replace 'enter-dir
              (lambda _ (chdir ,name) #t))
+           (add-before 'install 'adjust-semanage-conf-location
+             (lambda _
+               (substitute* "src/Makefile"
+                 (("DEFAULT_SEMANAGE_CONF_LOCATION=/etc")
+                  "DEFAULT_SEMANAGE_CONF_LOCATION=$(PREFIX)/etc"))
+               #t))
            (add-after 'build 'pywrap
              (lambda* (#:key make-flags #:allow-other-keys)
-               (zero? (apply system* "make" "pywrap" make-flags))))
+               (apply invoke "make" "pywrap" make-flags)))
            (add-after 'install 'install-pywrap
              (lambda* (#:key make-flags #:allow-other-keys)
-               (zero? (apply system* "make" "install-pywrap" make-flags))))))))
+               (apply invoke "make" "install-pywrap" make-flags)))))))
     (inputs
      `(("libsepol" ,libsepol)
        ("libselinux" ,libselinux)
        ("audit" ,audit)
-       ("ustr" ,ustr)
        ;; For pywrap phase
        ("python" ,python-wrapper)))
     (native-inputs
@@ -220,7 +241,7 @@ binary policies.")
     (license license:lgpl2.1+)))
 
 (define-public secilc
-  (package (inherit libsepol)
+  (package/inherit libsepol
     (name "secilc")
     (arguments
      (substitute-keyword-arguments (package-arguments libsepol)
@@ -233,6 +254,7 @@ binary policies.")
                  ,flags)))
        ((#:phases phases)
         `(modify-phases ,phases
+           (delete 'portability)
            (replace 'enter-dir
              (lambda _ (chdir ,name) #t))))))
     (inputs
@@ -246,7 +268,7 @@ binary policies.")
     (license license:bsd-2)))
 
 (define-public python-sepolgen
-  (package (inherit libsepol)
+  (package/inherit libsepol
     (name "python-sepolgen")
     (arguments
      `(#:modules ((srfi srfi-1)
@@ -255,8 +277,9 @@ binary policies.")
        ,@(substitute-keyword-arguments (package-arguments libsepol)
            ((#:phases phases)
             `(modify-phases ,phases
+               (delete 'portability)
                (replace 'enter-dir
-                 (lambda _ (chdir "sepolgen") #t))
+                 (lambda _ (chdir "python/sepolgen") #t))
                ;; By default all Python files would be installed to
                ;; $out/gnu/store/...-python-.../, so we override the
                ;; PACKAGEDIR to fix this.
@@ -297,25 +320,25 @@ based on required access.")
     ;; GPLv2 only
     (license license:gpl2)))
 
-;; The latest 4.1.x version does not work with the latest 2.6 release of
-;; policycoreutils, so we use the last 4.0.x release.
 (define-public python-setools
   (package
     (name "python-setools")
-    (version "4.0.1")
+    (version "4.1.1")
     (source (origin
-              (method url-fetch)
-              (uri (string-append "https://github.com/TresysTechnology/"
-                                  "setools/archive/" version ".tar.gz"))
-              (file-name (string-append name "-" version ".tar.gz"))
+              (method git-fetch)
+              (uri (git-reference
+                    (url "https://github.com/TresysTechnology/setools")
+                    (commit version)))
+              (file-name (string-append name "-" version "-checkout"))
               (sha256
                (base32
-                "1zndpl4ck5c23p7s4sci06db89q1w87jig3jbd4f8s1ggy3lj82c"))))
+                "0459xxly6zzqc5azcwk3rbbcxvj60dq08f8z6xr05y7dsbb16cg6"))))
     (build-system python-build-system)
     (arguments
      `(#:tests? #f ; the test target causes a rebuild
        #:phases
        (modify-phases %standard-phases
+         (delete 'portability)
          (add-after 'unpack 'set-SEPOL-variable
            (lambda* (#:key inputs #:allow-other-keys)
              (setenv "SEPOL"
@@ -350,12 +373,8 @@ tools, and libraries designed to facilitate SELinux policy analysis.")
                    license:gpl2+))))
 
 (define-public policycoreutils
-  (package (inherit libsepol)
+  (package/inherit libsepol
     (name "policycoreutils")
-    (source
-     (origin (inherit (package-source libsepol))
-             (patches (search-patches "policycoreutils-make-sepolicy-use-python3.patch"))
-             (patch-flags '("-p1" "-d" "policycoreutils"))))
     (arguments
      `(#:test-target "test"
        #:make-flags
@@ -382,15 +401,11 @@ tools, and libraries designed to facilitate SELinux policy analysis.")
        #:phases
        (modify-phases %standard-phases
          (delete 'configure)
+         (delete 'portability)
          (add-after 'unpack 'enter-dir
            (lambda _ (chdir ,name) #t))
          (add-after 'enter-dir 'ignore-/usr-tests
            (lambda* (#:key inputs #:allow-other-keys)
-             ;; The Makefile decides to build restorecond only if it finds the
-             ;; inotify header somewhere under /usr.
-             (substitute* "Makefile"
-               (("ifeq.*") "")
-               (("endif.*") ""))
              ;; Rewrite lookup paths for header files.
              (substitute* '("newrole/Makefile"
                             "setfiles/Makefile"
@@ -399,79 +414,13 @@ tools, and libraries designed to facilitate SELinux policy analysis.")
                 (string-append (assoc-ref inputs "pam") file))
                (("/usr(/include/libaudit.h)" _ file)
                 (string-append (assoc-ref inputs "audit") file)))
-             #t))
-         (add-after 'enter-dir 'fix-glib-cflags
-           (lambda* (#:key inputs #:allow-other-keys)
-             (substitute* "restorecond/Makefile"
-               (("/usr(/include/glib-2.0|/lib/glib-2.0/include)" _ path)
-                (string-append (assoc-ref inputs "glib") path))
-               (("/usr(/include/dbus-1.0|/lib/dbus-1.0/include)" _ path)
-                (string-append (assoc-ref inputs "dbus") path
-                               " -I"
-                               (assoc-ref inputs "dbus-glib") path)))
-             #t))
-         (add-after 'enter-dir 'fix-linkage-with-libsepol
-           (lambda* (#:key inputs #:allow-other-keys)
-             (substitute* '("semodule_deps/Makefile"
-                            "sepolgen-ifgen/Makefile")
-               (("\\$\\(LIBDIR\\)")
-                (string-append (assoc-ref inputs "libsepol") "/lib/")))))
-         (add-after 'enter-dir 'fix-target-paths
-           (lambda* (#:key outputs #:allow-other-keys)
-             (let ((out (assoc-ref outputs "out")))
-               (substitute* "audit2allow/sepolgen-ifgen"
-                 (("ATTR_HELPER = \"/usr/bin/sepolgen-ifgen-attr-helper\"")
-                  (string-append "ATTR_HELPER = \"" out
-                                 "/bin/sepolgen-ifgen-attr-helper\"")))
-               (substitute* "sepolicy/sepolicy/__init__.py"
-                 (("/usr/bin/sepolgen-ifgen")
-                  (string-append out "/bin/sepolgen-ifgen")))
-               (substitute* "sepolicy/Makefile"
-                 ;; By default all Python files would be installed to
-                 ;; $out/gnu/store/...-python-.../.
-                 (("setup.py install.*$")
-                  (string-append "setup.py install --prefix=" out "\n"))
-                 (("\\$\\(DESTDIR\\)/etc")
-                  (string-append out "/etc"))
-                 (("\\$\\(DESTDIR\\)/usr") out)))
-             #t))
-         (add-after 'install 'wrap-python-tools
-           (lambda* (#:key outputs #:allow-other-keys)
-             (let* ((out (assoc-ref outputs "out"))
-                    (var (string-append out "/lib/python"
-                                        ,(version-major+minor (package-version python))
-                                        "/site-packages:"
-                                        (getenv "PYTHONPATH"))))
-               ;; The scripts' shebangs tell Python to ignore the PYTHONPATH,
-               ;; so we need to patch them before wrapping.
-               (for-each (lambda (file)
-                           (let ((path (string-append out "/" file)))
-                             (substitute* path
-                               (("bin/python -Es") "bin/python -s"))
-                             (wrap-program path
-                               `("PYTHONPATH" ":" prefix (,var)))))
-                         '("bin/audit2allow"
-                           "bin/chcat"
-                           "bin/sandbox"
-                           "bin/sepolgen-ifgen"
-                           "bin/sepolicy"
-                           "sbin/semanage")))
              #t)))))
     (inputs
-     `(("python" ,python-wrapper)
-       ("audit" ,audit)
+     `(("audit" ,audit)
        ("pam" ,linux-pam)
        ("libsepol" ,libsepol)
        ("libselinux" ,libselinux)
-       ("libsemanage" ,libsemanage)
-       ("python-sepolgen" ,python-sepolgen)
-       ("python-setools" ,python-setools)
-       ("python-ipy" ,python-ipy)
-       ("libcap-ng" ,libcap-ng)
-       ("pcre" ,pcre)
-       ("dbus" ,dbus)
-       ("dbus-glib" ,dbus-glib)
-       ("glib" ,glib)))
+       ("libsemanage" ,libsemanage)))
     (native-inputs
      `(("gettext" ,gettext-minimal)))
     (synopsis "SELinux core utilities")
