@@ -235,25 +235,21 @@ exact build phases are defined by PHASES."
       (source s)
       (arguments
        ;; Use the right phases and modules.
-       (let* ((args (default-keyword-arguments (package-arguments p)
-                      `(#:phases #f
-                        #:modules ,%default-modules
-                        #:imported-modules ,%gnu-build-system-modules))))
-         (substitute-keyword-arguments args
-           ((#:modules modules)
-            `((guix build gnu-dist)
-              ,@modules))
-           ((#:imported-modules modules)
-            `((guix build gnu-dist)
-              ,@modules))
-           ((#:phases _)
-            phases))))
+       (substitute-keyword-arguments (package-arguments p)
+         ((#:modules modules %default-modules)
+          `((guix build gnu-dist)
+            ,@modules))
+         ((#:imported-modules modules %gnu-build-system-modules)
+          `((guix build gnu-dist)
+            ,@modules))
+         ((#:phases _ #f)
+          phases)))
       (native-inputs
        ;; Add autotools & co. as inputs.
        (let ((ref (lambda (module var)
                     (module-ref (resolve-interface module) var))))
          `(,@(package-native-inputs p)
-           ("autoconf" ,((ref '(gnu packages autotools) 'autoconf-wrapper)))
+           ("autoconf" ,(ref '(gnu packages autotools) 'autoconf-wrapper))
            ("automake" ,(ref '(gnu packages autotools) 'automake))
            ("libtool"  ,(ref '(gnu packages autotools) 'libtool))
            ("gettext"  ,(ref '(gnu packages gettext) 'gnu-gettext))
@@ -296,13 +292,19 @@ standard packages used as implicit inputs of the GNU build system."
                           `(("source" ,source))
                           '())
                     ,@native-inputs
+
+                    ;; When not cross-compiling, ensure implicit inputs come
+                    ;; last.  That way, libc headers come last, which allows
+                    ;; #include_next to work correctly; see
+                    ;; <https://bugs.gnu.org/30756>.
+                    ,@(if target '() inputs)
                     ,@(if (and target implicit-cross-inputs?)
                           (standard-cross-packages target 'host)
                           '())
                     ,@(if implicit-inputs?
                           (standard-packages)
                           '())))
-    (host-inputs inputs)
+    (host-inputs (if target inputs '()))
 
     ;; The cross-libc is really a target package, but for bootstrapping
     ;; reasons, we can't put it in 'host-inputs'.  Namely, 'cross-gcc' is a
@@ -454,13 +456,19 @@ is one of `host' or `target'."
            (libc      (module-ref cross 'cross-libc)))
       (case kind
         ((host)
+         ;; Cross-GCC appears once here, so that it's in $PATH...
          `(("cross-gcc" ,(gcc target
                               #:xbinutils (binutils target)
                               #:libc (libc target)))
            ("cross-binutils" ,(binutils target))))
         ((target)
          (let ((libc (libc target)))
-           `(("cross-libc" ,libc)
+           ;; ... and once here, so that libstdc++ & co. are in
+           ;; CROSS_CPLUS_INCLUDE_PATH, etc.
+           `(("cross-gcc" ,(gcc target
+                                #:xbinutils (binutils target)
+                                #:libc libc))
+             ("cross-libc" ,libc)
 
              ;; MinGW's libc doesn't have a "static" output.
              ,@(if (member "static" (package-outputs libc))
@@ -505,9 +513,11 @@ platform."
   (define canonicalize-reference
     (match-lambda
      ((? package? p)
-      (derivation->output-path (package-cross-derivation store p system)))
+      (derivation->output-path (package-cross-derivation store p
+                                                         target system)))
      (((? package? p) output)
-      (derivation->output-path (package-cross-derivation store p system)
+      (derivation->output-path (package-cross-derivation store p
+                                                         target system)
                                output))
      ((? string? output)
       output)))
