@@ -50,7 +50,7 @@
   "Return a URI string for the Python package hosted on the Python Package
 Index (PyPI) corresponding to NAME and VERSION.  EXTENSION is the file name
 extension, such as '.tar.gz'."
-  (string-append "https://pypi.org/packages/source/"
+  (string-append "https://files.pythonhosted.org/packages/source/"
                  (string-take name 1) "/" name "/"
                  name "-" version extension))
 
@@ -98,8 +98,7 @@ pre-defined variants."
 
      ;; Otherwise build the new package object graph.
      ((eq? (package-build-system p) python-build-system)
-      (package
-        (inherit p)
+      (package/inherit p
         (location (package-location p))
         (name (let ((name (package-name p)))
                 (string-append new-prefix
@@ -131,8 +130,7 @@ pre-defined variants."
 
 (define (strip-python2-variant p)
   "Remove the 'python2-variant' property from P."
-  (package
-    (inherit p)
+  (package/inherit p
     (properties (alist-delete 'python2-variant (package-properties p)))))
 
 (define* (lower name
