@@ -16,6 +16,7 @@
 ;;; Copyright © 2017 Rutger Helling <rhelling@mykolab.com>
 ;;; Copyright © 2020 André Batista <nandre@riseup.net>
 ;;; Copyright © 2020 Helio Machado <0x2b3bfa0+guix@googlemail.com>
+;;; Copyright © 2021 Felix Gruber <felgru@posteo.net>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -39,7 +40,7 @@
             apsl2
             asl1.1 asl2.0
             boost1.0
-            bsd-2 bsd-3 bsd-4
+            bsd-0 bsd-2 bsd-3 bsd-4
             non-copyleft
             cc0
             cc-by2.0 cc-by3.0 cc-by4.0
@@ -61,13 +62,14 @@
             gpl1 gpl1+ gpl2 gpl2+ gpl3 gpl3+
             gfl1.0
             fdl1.1+ fdl1.2+ fdl1.3+
-            opl1.0+
+            opl1.0+ osl2.1
             isc
             ijg
             ibmpl1.0
             imlib2
             ipa
             knuth
+            lal1.3
             lgpl2.0 lgpl2.0+ lgpl2.1 lgpl2.1+ lgpl3 lgpl3+ llgpl
             lppl lppl1.0+ lppl1.1+ lppl1.2 lppl1.2+
             lppl1.3 lppl1.3+
@@ -78,7 +80,7 @@
             mpl1.0 mpl1.1 mpl2.0
             ms-pl
             ncsa
-            npsl
+            nmap
             ogl-psi1.0
             openldap2.8 openssl
             perl-license
@@ -159,6 +161,11 @@
            "http://directory.fsf.org/wiki/License:Boost1.0"
            "https://www.gnu.org/licenses/license-list#boost"))
 
+(define bsd-0
+  (license "Zero-Clause BSD"
+           "https://spdx.org/licenses/0BSD.html"
+           "https://opensource.org/licenses/0BSD"))
+
 (define bsd-2
   (license "FreeBSD"
            "http://directory.fsf.org/wiki/License:FreeBSD"
@@ -371,6 +378,11 @@ at URI, which may be a file:// URI pointing the package's tree."
            "http://opencontent.org/openpub/"
            "https://www.gnu.org/licenses/license-list#OpenPublicationL"))
 
+(define osl2.1
+  (license "The Open Software License 2.1"
+           "https://opensource.org/licenses/osl-2.1.php"
+           "https://www.gnu.org/licenses/license-list#OSL"))
+
 (define isc
   (license "ISC"
            "http://directory.fsf.org/wiki/License:ISC"
@@ -401,6 +413,11 @@ at URI, which may be a file:// URI pointing the package's tree."
            "http://www.ctan.org/license/knuth"
            "Modification are only permitted under a different name."))
 
+(define lal1.3
+  (license "Free Art License 1.3"
+           "http://artlibre.org/licence/lal/en/"
+           "https://www.gnu.org/licenses/license-list#FreeArt"))
+
 (define lgpl2.0
   (license "LGPL 2.0"
            "https://www.gnu.org/licenses/old-licenses/lgpl-2.0.html"
@@ -531,10 +548,10 @@ at URI, which may be a file:// URI pointing the package's tree."
            "http://directory.fsf.org/wiki/License:IllinoisNCSA"
            "https://www.gnu.org/licenses/license-list#NCSA"))
 
-(define npsl
-  (license "Nmap Public Source License"
-           "https://svn.nmap.org/nmap/LICENSE"
-           "https://nmap.org/npsl/"))
+(define nmap
+  (license "Nmap license"
+           "https://svn.nmap.org/nmap/COPYING"
+           "https://fedoraproject.org/wiki/Licensing/Nmap"))
 
 (define ogl-psi1.0
   (license "Open Government Licence for Public Sector Information"
