@@ -1,5 +1,5 @@
 ;;; GNU Guix --- Functional package management for GNU
-;;; Copyright © 2015 Ludovic Courtès <ludo@gnu.org>
+;;; Copyright © 2015, 2021 Ludovic Courtès <ludo@gnu.org>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -19,7 +19,8 @@
 (define-module (test-gnu-maintenance)
   #:use-module (guix gnu-maintenance)
   #:use-module (srfi srfi-1)
-  #:use-module (srfi srfi-64))
+  #:use-module (srfi srfi-64)
+  #:use-module (ice-9 match))
 
 (test-begin "gnu-maintenance")
 
@@ -29,7 +30,11 @@
               '(("gcc" "gcc-5.3.0.tar.bz2")
                 ("texmacs" "TeXmacs-1.0.7.9-src.tar.gz")
                 ("icecat" "icecat-38.4.0-gnu1.tar.bz2")
-                ("mit-scheme" "mit-scheme-9.2.tar.gz")))
+                ("mit-scheme" "mit-scheme-9.2.tar.gz")
+                ("mediainfo" "mediainfo_20.09.tar.xz")
+                ("exiv2" "exiv2-0.27.3-Source.tar.gz")
+                ("mpg321" "mpg321_0.3.2.orig.tar.gz")
+                ("bvi" "bvi-1.4.1.src.tar.gz")))
        (every (lambda (project+file)
                 (not (apply release-file? project+file)))
               '(("guile" "guile-www-1.1.1.tar.gz")
@@ -38,4 +43,15 @@
                 ("mit-scheme" "mit-scheme-9.2-doc-pdf.tar.gz")
                 ("gnutls" "gnutls-3.2.18-w32.zip")))))
 
+(test-assert "tarball->version"
+  (let ((tarball->version (@@ (guix gnu-maintenance) tarball->version)))
+    (every (match-lambda
+             ((file version)
+              (equal? (tarball->version file) version)))
+           '(("coreutils-8.32.tar.gz" "8.32")
+             ("mediainfo_20.09.tar.xz" "20.09")
+             ("exiv2-0.27.3-Source.tar.gz" "0.27.3")
+             ("mpg321_0.3.2.orig.tar.gz" "0.3.2")
+             ("bvi-1.4.1.src.tar.gz" "1.4.1")))))
+
 (test-end)
